/* *****************************************************************************
;                                                                             *
;    Filename:                     				                              *
;    Date:                                         	                          *
;    File Version: 001                                                        *
;                                                                             *
;    Author:   Jason Lopez                                                    *
;    Company:  AtomSoft                                                       *
;                                                                             *
;***************************************************************************** */

#include <p18f2525.h>
#include <delays.h>
#include <string.h>

#pragma config OSC = INTIO67,PWRT = OFF,BOREN = OFF,WDT = OFF,PBADEN = OFF

/************************************
Prototypes
*************************************/
void main(void);
void USART_Init(void);
unsigned char USART_vReceiveByte(void);
void delayms( unsigned char t);
void high_isr (void);
void interrupt_at_high_vector(void);

/************************************
Definitions and Variables
*************************************/
#define SYNC 0XAA// synchro signal
#define RADDR 0x44
#define LEDON 0x11//switch led on command
#define LEDOFF 0x22//switch led off command

/************************************
Main
*************************************/
#pragma code high_vector=0x08
void interrupt_at_high_vector(void)
{
  _asm GOTO high_isr _endasm
}
#pragma code /* return to the default code section */

#pragma interrupt high_isr
void high_isr (void)
{
	//define variables
	unsigned char raddress, data, chk = 0;//transmitter address
	//receive destination address
	raddress=USART_vReceiveByte();
	//receive data
	data=USART_vReceiveByte();
	//receive checksum
	chk=USART_vReceiveByte();
	//compare received checksum with calculated
	if(chk==(raddress+data))//if match perform operations
	{
		//if transmitter address match
		if(raddress==RADDR)
			{
				if(data==LEDON)
					{
						LATCbits.LATC1 = 1;//LED ON
					}
				else if(data==LEDOFF)
					{
						LATCbits.LATC1 = 0;//LED OFF
					}
			}
		}else{
			//blink led as error
			LATCbits.LATC2 = 0;//LED OFF
			delayms(10);
			LATCbits.LATC2 = 1;//LED ON
		}
    /* Clear the interrupt flag */
    PIR1bits.RCIF = 0;
}

void main(void){
	OSCCON = 0x72;      			//8MHz clock
	while(!OSCCONbits.IOFS);		//wait for osc stable

	ADCON1 = 0x0F;
	TRISC = 0;
	USART_Init();

	while(1){
	}
}

void USART_Init(void)
{
   	TRISCbits.TRISC7 = 1;	//SETUP UART
    TXSTA = 0;
    SPBRG = 103;     //1200bps

    RCONbits.IPEN = 1;
    IPR1bits.RCIP = 1; //PRIORITY

    TXSTAbits.TXEN = 1;  //ENABLE TX
    RCSTAbits.CREN = 1;  //ENABLE RX
    RCSTAbits.SPEN = 1;  //ENABLE SERIAL PORT and PIN Config

    PIE1bits.RCIE = 1;      //ENABLE RX Interrupt
    PIR1   = 0b00000000;
    PIE1   = 0b00101000;
    IPR1   = 0b00101000;
    INTCON = 0b11000000;
}

unsigned char USART_vReceiveByte(void)
{
    // Wait until a byte has been received
    while(!PIR1bits.RCIF);
    // Return received data
    return RCREG;
}

void delayms( unsigned char t)
{
	unsigned char i;
	for(i=0;i<t;i++)
		Delay1KTCYx(2);
}

