/* *****************************************************************************
;                                                                             *
;    Filename:                     				                              *
;    Date:                                         	                          *
;    File Version: 001                                                        *
;                                                                             *
;    Author:   Jason Lopez                                                    *
;    Company:  AtomSoft                                                       *
;                                                                             *
;***************************************************************************** */

#include <p18f2525.h>
#include <delays.h>
#include <string.h>

#pragma config OSC = INTIO67,PWRT = OFF,BOREN = OFF,WDT = OFF,PBADEN = OFF

/************************************
Prototypes
*************************************/
void main(void);
void USART_Init(void);
void USART_vSendByte( unsigned char u8Data);
void Send_Packet( unsigned char addr,  unsigned char cmd);
void delayms( unsigned char t);


/************************************
Definitions and Variables
*************************************/
#define SYNC 0XAA// synchro signal
#define RADDR 0x44
#define LEDON 0x11//switch led on command
#define LEDOFF 0x22//switch led off command

/************************************
Main
*************************************/
void main(void){
	OSCCON = 0x72;      			//8MHz clock
	while(!OSCCONbits.IOFS);		//wait for osc stable

	USART_Init();

	while(1){
		//endless transmission
		//send command to switch led ON
		Send_Packet(RADDR, LEDON);
		delayms(100);
		//send command to switch led ON
		Send_Packet(RADDR, LEDOFF);
		delayms(100);
		}
}

void USART_Init(void)
{
   	TRISCbits.TRISC7 = 1;	//SETUP UART
    TXSTA = 0;
    SPBRG = 103;     //1200bps

    TXSTAbits.TXEN = 1;  //ENABLE TX
    RCSTAbits.SPEN = 1;  //ENABLE SERIAL PORT and PIN Config
}

void USART_vSendByte( unsigned char u8Data)
{
    // Wait if a byte is being transmitted
    while(!TXSTAbits.TRMT);
    // Transmit data
	TXREG = u8Data;
}

void Send_Packet( unsigned char addr,  unsigned char cmd)
{
	USART_vSendByte(SYNC);//send synchro byte	
	USART_vSendByte(addr);//send receiver address
	USART_vSendByte(cmd);//send increment command
	USART_vSendByte((addr+cmd));//send checksum
}

void delayms( unsigned char t)
{
	unsigned char i;
	for(i=0;i<t;i++)
		Delay1KTCYx(2);
}
